@@ -1,4 +1,4 @@
-package Finance::Alpaca 0.9902 {
+package Finance::Alpaca 0.9903 {
     use strictures 2;
     use Moo;
     use feature 'signatures';
@@ -121,31 +121,35 @@ package Finance::Alpaca 0.9902 {
             $_ . '='
                 . ( ref $params{$_} eq 'Time::Moment' ? $params{$_}->to_string() : $params{$_} )
         } keys %params if keys %params;
-        return (
-            Dict [ quotes => ArrayRef [Quote], symbol => Str, next_page_token => Maybe [Str] ] )
-            ->assert_coerce(
-            $s->ua->get(
-                sprintf 'https://data.alpaca.markets/v%d/stocks/%s/quotes%s',
-                $s->api_version, $symbol, $params
-            )->result->json
-            );
+        my $res = $s->ua->get(
+            sprintf 'https://data.alpaca.markets/v%d/stocks/%s/quotes%s',
+            $s->api_version, $symbol, $params
+        )->result;
+        return $res->is_error ? $res->json : (
+            ( next_page_token => $res->json->{next_page_token} ),
+            map { delete $_->{symbol} => delete $_->{quotes} } (
+                Dict [ quotes => ArrayRef [Quote], symbol => Str, next_page_token => Maybe [Str] ]
+            )->assert_coerce( $res->json )
+        );
     }
 
     sub trades ( $s, %params ) {
         my $symbol = delete $params{symbol};
-        my $params = '';
-        $params .= '?' . join '&', map {
-            $_ . '='
-                . ( ref $params{$_} eq 'Time::Moment' ? $params{$_}->to_string() : $params{$_} )
-        } keys %params if keys %params;
-        return (
-            Dict [ trades => ArrayRef [Trade], symbol => Str, next_page_token => Maybe [Str] ] )
-            ->assert_coerce(
-            $s->ua->get(
-                sprintf 'https://data.alpaca.markets/v%d/stocks/%s/trades%s',
-                $s->api_version, $symbol, $params
-            )->result->json
-            );
+        for ( keys %params ) {
+            $params{$_} = $params{$_}->to_string() if ref $params{$_} eq 'Time::Moment';
+        }
+        my $res = $s->ua->get(
+            sprintf(
+                'https://data.alpaca.markets/v%d/stocks/%s/trades',
+                $s->api_version, $symbol
+            ) => form => {%params}
+        )->result;
+        return $res->is_error ? $res->json : (
+            ( next_page_token => $res->json->{next_page_token} ),
+            map { delete $_->{symbol} => delete $_->{trades} } (
+                Dict [ trades => ArrayRef [Trade], symbol => Str, next_page_token => Maybe [Str] ]
+            )->assert_coerce( $res->json )
+        );
     }
 
     sub trade_stream ( $s, $cb, %params ) {
@@ -174,24 +178,29 @@ package Finance::Alpaca 0.9902 {
     }
 
     sub orders ( $s, %params ) {
-        my $params = '';
-        $params .= '?' . join '&', map {
-            $_ . '='
-                . ( ref $params{$_} eq 'Time::Moment' ? $params{$_}->to_string() : $params{$_} )
-        } keys %params if keys %params;
-        return ( ArrayRef [Order] )
-            ->assert_coerce( $s->ua->get( $s->endpoint . '/v2/orders' . $params )->result->json );
+        for ( keys %params ) {
+            $params{$_} = $params{$_}->to_string() if ref $params{$_} eq 'Time::Moment';
+        }
+        return @{
+            ( ArrayRef [Order] )->assert_coerce(
+                $s->ua->get( $s->endpoint . '/v2/orders' => form => {%params} )->result->json
+            )
+        };
     }
 
     sub order_by_id ( $s, $order_id, $nested = 0 ) {
-        my $res = $s->ua->get(
-            $s->endpoint . '/v2/orders/' . $order_id . ( $nested ? '?nested=1' : '' ) )->result;
+        my $res
+            = $s->ua->get(
+            $s->endpoint . '/v2/orders/' . $order_id => form => ( $nested ? { nested => 1 } : () ) )
+            ->result;
         return $res->is_error ? () : to_Order( $res->json );
     }
 
     sub order_by_client_id ( $s, $order_id ) {
-        my $res = $s->ua->get(
-            $s->endpoint . '/v2/orders:by_client_order_id?client_order_id=' . $order_id )->result;
+        my $res
+            = $s->ua->get( $s->endpoint
+                . '/v2/orders:by_client_order_id' => form => { client_order_id => $order_id } )
+            ->result;
         return $res->is_error ? () : to_Order( $res->json );
     }
 
@@ -276,8 +285,9 @@ package Finance::Alpaca 0.9902 {
     }
 
     sub watchlists ($s) {
-        return ( ArrayRef [Watchlist] )
-            ->assert_coerce( $s->ua->get( $s->endpoint . '/v2/watchlists' )->result->json );
+        return
+            @{ ( ArrayRef [Watchlist] )
+                ->assert_coerce( $s->ua->get( $s->endpoint . '/v2/watchlists' )->result->json ) };
     }
 
     sub create_watchlist ( $s, $name, @symbols ) {
@@ -499,7 +509,7 @@ found, an empty list is returned.
         start     => Time::Moment->now->with_hour(10),
         end       => Time::Moment->now->minus_minutes(20)
     );
- 
+
 Returns a list of L<Finance::Alpaca::Struct::Bar> objects along with other
 data.
 
@@ -528,7 +538,7 @@ symbol as well as a C<next_page_token> for pagination if applicable.
 
 =head2 C<quotes( ... )>
 
-    my $quotes = $camelid->quotes(
+    my %quotes = $camelid->quotes(
         symbol => 'MSFT',
         start  => Time::Moment->now->with_hour(10),
         end    => Time::Moment->now->minus_minutes(20)
@@ -556,21 +566,12 @@ The following parameters are accepted:
 
 =back
 
-The data returned includes the following data:
-
-=over
-
-=item C<quotes> - List of L<Finance::Alpaca::Struct::Quote> objects
-
-=item C<next_page_token> - Token that can be used to query the next page
-
-=item C<symbol> - Symbol that was queried
-
-=back
+The method returns a hash reference with quote data included as a list under
+the symbol as well as a C<next_page_token> for pagination if applicable.
 
 =head2 C<trades( ... )>
 
-    my $trades = $camelid->trades(
+    my %trades = $camelid->trades(
         symbol => 'MSFT',
         start  => Time::Moment->now->with_hour(10),
         end    => Time::Moment->now->minus_minutes(20)
@@ -598,17 +599,9 @@ The following parameters are accepted:
 
 =back
 
-The data returned includes the following data:
+The method returns a hash reference with trade data included as a list under
+the symbol as well as a C<next_page_token> for pagination if applicable.
 
-=over
-
-=item C<trades> - List of L<Finance::Alpaca::Struct::Quote> objects
-
-=item C<next_page_token> - Token that can be used to query the next page
-
-=item C<symbol> - Symbol that was queried
-
-=back
 
 =head2 C<trade_stream( ... )>
 
@@ -641,7 +634,7 @@ data.
 
 =head2 C<orders( [...] )>
 
-    my $orders = $camelid->orders( status => 'open' );
+    my @orders = $camelid->orders( status => 'open' );
 
 Returns a list of L<Finance::Alpaca::Struct::Order> objects.
 
